Credits — django-bakery 0.7.6 documentation

# Credits

This application was written by Ben Welsh, Ken Schwencke and Armand Emamdjomeh at the Los Angeles Times Data Desk.

The ideas behind django-bakery were first presented at the 2012 conference of the National Institute for Computer-Assisted Reporting. The NICAR community is a constant source of challenge and inspiration. Many of our ideas, here and elsewhere, have been adapted from things the community has taught us.